use std::io::BufReader;
use std::fs::File;

use handlebars::Handlebars;

use crate::exit::exit_with_error;

fn default_ldap_url() -> String {
    "ldap://localhost".to_string()
}

fn default_host() -> String {
    "localhost".to_string()
}

fn default_port() -> u16 {
    8000
}

#[derive(Deserialize)]
pub struct Config {
    pub dn: String,

    #[serde(default = "default_ldap_url")]
    pub ldap_url: String,

    #[serde(default = "default_host")]
    pub host: String,

    #[serde(default = "default_port")]
    pub port: u16,
}

pub fn check_config(config: Config) -> Config {
    let hb = Handlebars::new();

    if let Some(e) = hb.render_template(&config.dn, &json!({"username" : "foo"})).err() {
        exit_with_error(&format!("Failed to parse 'dn' ({}) in configuration file: {}", config.dn, e))
    };

    config
}

pub fn load_config(file_path: &str) -> Config {
    let file = match File::open(file_path) {
        Ok(file) => file,
        Err(_) => exit_with_error(&format!("Failed to open configuration file '{}'", file_path))
    };

    let reader = BufReader::new(file);

    match serde_json::from_reader::<BufReader<_>, Config>(reader) {
        Ok(config) => check_config(config),
        Err(_) => exit_with_error(&format!("Failed to parse configuration file '{}'", file_path))
    }
}
