MODAL_STATES = {
  "Wait" : {
    button_disabled : true,
    message : "Waiting for server response ...",
    icon_url : "hourglass.svg",
  },
  "Success" : {
    button_disabled : false,
    message : "Password changed",
    icon_url : "checkmark.svg",
  },
  "FetchError" : {
    button_disabled : false,
    message : function(parameters) { `An error occurred while contacting the server ({parameters.statusCode})` },
  },
  "ServerError" : {
    button_disabled : false,
    message : "A server error occurred. Password was not changed.",
    icon_url : "cross.svg",
  },
  "InvalidCredentials" : {
    button_disabled : false,
    message : "Invalid credentials provided. Password was not changed.",
    icon_url : "cross.svg",
  },
}

function showModal(state_name, parameters) {
  let state = MODAL_STATES[state_name];

  let message = document.getElementById("message");

  let img = message.childNodes[0];
  img.src = state.icon_url;

  let text = message.childNodes[1];
  text.textContent = " " + (state.message instanceof Function ? state.message(parameters) : state.message);

  let button = document.getElementById("close_button");
  button.disabled = state.button_disabled;

  let modal = document.getElementById("modal");
  modal.style.display = 'flex';
}

function hideModal() {
  let modal = document.getElementById("modal");
  modal.style.display = 'none';
}

FIELDS = ['username', 'old_password', 'new_password']

function changePasswords() {
  let query = {};

  for (field in FIELDS) {
    query[FIELDS[field]] = document.querySelectorAll('input[name=' + FIELDS[field] + ']')[0].value;
  }

  showModal("Wait");

  fetch("update", {
    method: "POST",
    body: JSON.stringify(query),
  }).then(response => {
    if(response.status == 200) {
      return response.json();
    } else {
      showModal("FetchError", { statusCode : response.status });
    }
  }).then(response => {
      if(response.success) {
        showModal("Success");
      } else {
        showModal(response.message);
      }
  });
}
